Snapchat
--------

App registration (get your key and secret here)
    https://kit.snapchat.com/manage/

Development callback URL
    http://example.com/accounts/snap/login/callback/

API documentation
    https://docs.snap.com/docs/snap-kit/login-kit/overview
